/*****************************************************************************
 *
 *  Purpose:    This application is to demonstrate how to call the
 *              ContactAtOnce Reporting Service webservice
 * 
 *  Documentation: http://www.contactatonce.com/support/ReportingService.html
 * 
 *  DISCLAIMER: This reference application is provided "as is" with no
 *  express or implied warranty.  ContactAtOnce! provides this source code
 *  as a matter of convenience to customers that wish to integrate to the
 *  ContactAtOnce! web service APIs.
 * 
 *****************************************************************************/

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using ReportingServiceApp.com.contactatonce.applications;

namespace ReportingServiceApp
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }
        private void Form1_Load(object sender, EventArgs e)
        {
            // Initialize form fields
            txtID.Text = "";        //ProviderID
            txtUserName.Text = "";  //Webservice Username
            txtPassword.Text = "";  // Webservice Password
            tcFilterOptions.SelectedIndex = 0;
        }


        private void btnGetStatisticsSummary_Click(object sender, EventArgs e)
        {
            // Define service, credential, and filter objects
            ContactAtOnceReportingService service = new ContactAtOnceReportingService();
            ProviderCredential credential = new ProviderCredential();
            ReportFilterCriteria filter = new ReportFilterCriteria();

            // Set credential values
            credential.Id = Convert.ToInt32(txtID.Text);
            credential.UserName = Convert.ToString(txtUserName.Text);
            credential.Password = Convert.ToString(txtPassword.Text);

            // Set filter values
            filter.StartDate = new DateTime(dtpFilterStartDate.Value.Date.Year,
                            dtpFilterStartDate.Value.Date.Month,
                            dtpFilterStartDate.Value.Date.Day,
                            0, 0, 0);
            filter.EndDate = new DateTime(dtpFilterEndDate.Value.Date.Year,
                            dtpFilterEndDate.Value.Date.Month,
                            dtpFilterEndDate.Value.Date.Day,
                            23, 59, 59);
            filter.AdvertiserId = txtFilterAdvertiserId.Text;

            try
            {
                // Call CAO webservice
                ReportStat[] results = service.GetStatisticsSummary(credential, filter);
                StringBuilder output = new StringBuilder(4096);

                // Set output headers
                output.AppendLine(
                    "AdvertiserId|" +
                    "AdvertiserName|" +
                    "Impressions|" +
                    "NumberEmails|" +
                    "NumberIMConversations|" +
                    "NumberPhoneCalls|" +
                    "Present|" +
                    "TotalLeads|" +
                    "UniqueImpressions|" +
                    "UniquePresent|"
                ); // output.AppendLine

                // Build output
                for (int i = results.GetLowerBound(0); i <= results.GetUpperBound(0); i++)
                {
                    output.AppendLine(
                       results[i].AdvertiserId + "|" +
                       results[i].AdvertiserName + "|" +
                       results[i].Impressions + "|" +
                       results[i].NumberEmails + "|" +
                       results[i].NumberIMConversations + "|" +
                       results[i].NumberPhoneCalls + "|" +
                       results[i].Present + "|" +
                       results[i].TotalLeads + "|" +
                       results[i].UniqueImpressions + "|" +
                       results[i].UniquePresent + "|"
                    ); // output.AppendLine
                } // for(i)
                
                // Display output
                txtResults.Text = output.ToString();
            }
            catch (Exception ex)
            {
                // Display any exception
                txtResults.Text = ex.Message;
            }
            return;
        }

        private void btnGetCallDetail_Click(object sender, EventArgs e)
        {
            // Define service, credential, and filter objects
            ContactAtOnceReportingService service = new ContactAtOnceReportingService();
            ProviderCredential credential = new ProviderCredential();
            ReportFilterCriteria filter = new ReportFilterCriteria();

            // Set credential values
            credential.Id = Convert.ToInt32(txtID.Text);
            credential.UserName = Convert.ToString(txtUserName.Text);
            credential.Password = Convert.ToString(txtPassword.Text);

            // Set filter values
            filter.StartDate = new DateTime(dtpFilterStartDate.Value.Date.Year,
                            dtpFilterStartDate.Value.Date.Month,
                            dtpFilterStartDate.Value.Date.Day,
                            0, 0, 0);
            filter.EndDate = new DateTime(dtpFilterEndDate.Value.Date.Year,
                            dtpFilterEndDate.Value.Date.Month,
                            dtpFilterEndDate.Value.Date.Day,
                            23, 59, 59);
            filter.AdvertiserId = txtFilterAdvertiserId.Text;

            try
            {
                // Call CAO webservice
                CallDetail[] results = service.GetCallDetail(credential, filter, txtTargetNumber.Text.ToString());
                StringBuilder output = new StringBuilder(4096);

                // Set output headers
                output.AppendLine(
                    "AdvertiserId|" +
                    "AdvertiserName|" +
                    "CustomerAddress.Address1|" +
                    "CustomerAddress.Address2|" +
                    "CustomerAddress.City|" +
                    "CustomerAddress.State|" +
                    "CustomerAddress.Zip|" +
                    "CustomerName|" +
                    "CustomerPhone|" +
                    "DialedNumber|" +
                    "Duration|" +
                    "EndTime|" +
                    "ForwardToNumber|" +
                    "PlaybackUrl|" +
                    "StartTime|" +
                    "Status|" +
                    "TrackedNumberApplication|" +
                    "TrackedNumberComment|" +
                    "Type|" +
                    "VisitId|"
                ); // output.AppendLine

                // Build output
                for (int i = results.GetLowerBound(0); i <= results.GetUpperBound(0); i++)
                {
                    output.AppendLine(
                        results[i].AdvertiserId+ "|"+
                        results[i].AdvertiserName+ "|"+
                        results[i].CustomerAddress.Address1+ "|"+
                        results[i].CustomerAddress.Address2+ "|"+
                        results[i].CustomerAddress.City+ "|"+
                        results[i].CustomerAddress.State+ "|"+
                        results[i].CustomerAddress.Zip+ "|"+
                        results[i].CustomerName+ "|"+
                        results[i].CustomerPhone+ "|"+
                        results[i].DialedNumber+ "|"+
                        results[i].Duration+ "|"+
                        results[i].EndTime+ "|"+
                        results[i].ForwardToNumber+ "|"+
                        results[i].PlaybackUrl+ "|"+
                        results[i].StartTime+ "|"+
                        results[i].Status+ "|"+
                        results[i].TrackedNumberApplication+ "|"+
                        results[i].TrackedNumberComment+ "|"+
                        results[i].Type+ "|"+
                        results[i].VisitId+ "|"
                    ); // output.AppendLine
                } // for(i)

                // Display output
                txtResults.Text = output.ToString();
            }
            catch (Exception ex)
            {
                // Display any exception
                txtResults.Text = ex.Message;
            }

            return;
        }

        private void btnGetImConversationTranscript_Click(object sender, EventArgs e)
        {
            // Define service and credential objects
            ContactAtOnceReportingService service = new ContactAtOnceReportingService();
            ProviderCredential credential = new ProviderCredential();

            // Set credential values
            credential.Id = Convert.ToInt32(txtID.Text);
            credential.UserName = Convert.ToString(txtUserName.Text);
            credential.Password = Convert.ToString(txtPassword.Text);

            try
            {
                // Call CAO webservice
                ImConversationTranscript results = service.GetImConversationTranscript(credential, Convert.ToInt64(txtVisitId.Text));
                StringBuilder output = new StringBuilder(4096);

                // Output Context and start time
                output.AppendLine(
                    "Context|" +
                    "StartTime|"
                ); // output.AppendLine

                output.AppendLine(
                    results.Context + "|" +
                    results.StartTime + "|"
                ); // output.AppendLine

                // Build output
                for (int i = results.Messages.GetLowerBound(0); i <= results.Messages.GetUpperBound(0); i++)
                {
                    output.AppendLine(
                        "" + "|"+
                        "" + "|"+
                        results.Messages[i].Timestamp + "|"+
                        results.Messages[i].SpeakerName + "|"+
                        results.Messages[i].SpeakerRole + "|"+
                        results.Messages[i].MessgeText + "|"
                    ); // output.AppendLine
                } // for(i)

                // Display output
                txtResults.Text = output.ToString();
            }
            catch (Exception ex)
            {
                // Display any exception
                txtResults.Text = ex.Message;
            }

            return;
        }

        private void btnGetLeadDetail_Click(object sender, EventArgs e)
        {
            // Define service, credential, and filter objects
            ContactAtOnceReportingService service = new ContactAtOnceReportingService();
            ProviderCredential credential = new ProviderCredential();
            ReportFilterCriteria filter = new ReportFilterCriteria();

            // Set credential values
            credential.Id = Convert.ToInt32(txtID.Text);
            credential.UserName = Convert.ToString(txtUserName.Text);
            credential.Password = Convert.ToString(txtPassword.Text);

            // Set filter values
            filter.StartDate = new DateTime(dtpFilterStartDate.Value.Date.Year,
                            dtpFilterStartDate.Value.Date.Month,
                            dtpFilterStartDate.Value.Date.Day,
                            0, 0, 0);
            filter.EndDate = new DateTime(dtpFilterEndDate.Value.Date.Year,
                            dtpFilterEndDate.Value.Date.Month,
                            dtpFilterEndDate.Value.Date.Day,
                            23, 59, 59);
            filter.AdvertiserId = txtFilterAdvertiserId.Text;
            try
            {
                // Call CAO webservice
                LeadStat[] results = service.GetLeadDetail(credential, filter);
                StringBuilder output = new StringBuilder(4096);

                // Set output headers
                output.AppendLine(
                    "AdvertiserId|" +
                    "AdvertiserName|" +
                    "AgentName|" +
                    "Attempt|" +
                    "CustomerAddress.Address1|" +
                    "CustomerAddress.Address2|" +
                    "CustomerAddress.City|" +
                    "CustomerAddress.State|" +
                    "CustomerAddress.Zip|" +
                    "CustomerEmail|" +
                    "CustomerName|" +
                    "CustomerPhone|" +
                    "ListingDetails|" +
                    "Timestamp|" +
                    "Type|" +
                    "VisitId|"
                ); // output.AppendLine

                // Build output
                for (int i = results.GetLowerBound(0); i <= results.GetUpperBound(0); i++)
                {
                    output.AppendLine(
                        results[i].AdvertiserId + "|" +
                        results[i].AdvertiserName + "|" +
                        results[i].AgentName + "|" +
                        results[i].Attempt + "|" +
                        results[i].CustomerAddress.Address1 + "|" +
                        results[i].CustomerAddress.Address2 + "|" + 
                        results[i].CustomerAddress.City + "|" +
                        results[i].CustomerAddress.State + "|" +
                        results[i].CustomerAddress.Zip + "|" +
                        results[i].CustomerEmail + "|" +
                        results[i].CustomerName + "|" +
                        results[i].CustomerPhone + "|" +
                        results[i].ListingDetails + "|" +
                        results[i].Timestamp + "|" +
                        results[i].Type + "|" +
                        results[i].VisitId + "|"
                    ); // output.AppendLine
                } // for(i)

                // Display output
                txtResults.Text = output.ToString();
            }
            catch (Exception ex)
            {
                // Display any exception
                txtResults.Text = ex.Message;
            }

            return;
        }

        private void tcFilterOptions_SelectedIndexChanged(object sender, EventArgs e)
        {
            // Set filter options based on selected tab
            switch (tcFilterOptions.SelectedTab.Name)
            {
                case "tabGetStatisticsSummary":
                    gbFilterCriteria.Enabled = true;
                    break;
                case "tabGetImConversationTranscript":
                    gbFilterCriteria.Enabled = false;
                    break;
                case "tabGetLeadDetail":
                    gbFilterCriteria.Enabled = true;
                    break;
                case "tabGetCallDetail":
                    gbFilterCriteria.Enabled = true;
                    break;
                default:
                    //do nothing
                    break;
            }
        }

    }
}